@@ -8,9 +8,9 @@ cat_line <- function(...) {
 
 is_windows <- function() .Platform$OS.type == "windows"
 
-is_mac     <- function() Sys.info()[['sysname']] == 'Darwin'
+is_mac <- function() Sys.info()[['sysname']] == 'Darwin'
 
-is_linux   <- function() Sys.info()[['sysname']] == 'Linux'
+is_linux <- function() Sys.info()[['sysname']] == 'Linux'
 
 is_openbsd <- function() Sys.info()[['sysname']] == "OpenBSD"
 
@@ -46,12 +46,10 @@ fetch_key_l <- function(x, key, default = stop("Key not present")) {
   vapply(x, get_key, key, default = default, FUN.VALUE = FALSE)
 }
 
-
 drop_nulls <- function(x) {
   x[!vapply(x, is.null, TRUE)]
 }
 
-
 # =============================================================================
 # Text
 # =============================================================================
@@ -66,7 +64,6 @@ truncate <- function(x, n = 1000, message = "[truncated]") {
   x
 }
 
-
 # =============================================================================
 # Protocol-related stuff
 # =============================================================================
@@ -76,7 +73,6 @@ find_domain <- function(event) {
   sub("\\.[^.]+", "", event)
 }
 
-
 # =============================================================================
 # Browser
 # =============================================================================
@@ -99,7 +95,6 @@ browse_url <- function(path, chromote) {
   }
 }
 
-
 # =============================================================================
 # Random Ports
 # =============================================================================
@@ -155,7 +150,8 @@ with_random_port <- function(
     err_fatal <- NULL
 
     # Try to run `startup` with the random port
-    tryCatch({
+    tryCatch(
+      {
         res <- startup(port = port, ...)
         success <- TRUE
       },
